@@ -7,33 +7,39 @@ import subprocess
 from typing import List
 
 
-def win_exec(command: List[str]) -> dict:
+def win_exec(command: List[str], capture_output=False) -> dict:
     """Execute given command.
 
     This command is executed using powershell.
 
     params:
         - command: list containing command that needs to be executed.
+        - capture_output: capture output of executed command on stdout and stderr.
 
     returns:
         - dict containing output of command on output key or error on error key.
     """
     result = subprocess.run(
-        ["powershell", " ".join(command)], check=False, text=True, capture_output=True
+        ["powershell", " ".join(command)],
+        check=False,
+        text=True,
+        capture_output=capture_output,
     )
-    return {
-        "error": result.stderr.rstrip().lstrip(),
-        "output": result.stdout.rstrip().lstrip(),
-    }
+    output = {"code": str(result.returncode)}
+    if capture_output:
+        output["output"] = result.stdout.rstrip().lstrip()
+        output["error"] = result.stderr.rstrip().lstrip()
+    return output
 
 
-def posix_exec(command: List[str]) -> dict:
+def posix_exec(command: List[str], capture_output=False) -> dict:
     """Execute given command.
 
     This command is executed using bash.
 
     params:
         - command: list containing command that needs to be executed.
+        - capture_output: capture output of executed command on stdout and stderr.
 
     returns:
         - dict containing output of command on output key or error on error key.
@@ -42,9 +48,10 @@ def posix_exec(command: List[str]) -> dict:
         ["/bin/bash", "-c", " ".join(command)],
         check=False,
         text=True,
-        capture_output=True,
+        capture_output=capture_output,
     )
-    return {
-        "error": result.stderr.rstrip().lstrip(),
-        "output": result.stdout.rstrip().lstrip(),
-    }
+    output = {"code": str(result.returncode)}
+    if capture_output:
+        output["output"] = result.stdout.rstrip().lstrip()
+        output["error"] = result.stderr.rstrip().lstrip()
+    return output
